@@ -2,25 +2,25 @@ package POEIKC;
 
 use strict;
 use 5.8.1;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 __END__
 
 =head1 NAME
 
-POEIKC - POE IKC daemon and client
+POEIKC - A framework to make a daemon or P2P with "PoCo::IKC"
 
 =head1 SYNOPSIS
 
 L<poeikcd> (daemon)
 
-	poeikcd start -p=47225 
-	poeikcd stop  -p=47225 
+	poeikcd start -p=47225
+	poeikcd stop  -p=47225
 	poeikcd --help
 
-And then 
-L<poikc> (client) 
+And then
+L<poikc> (client)
 
 	poikc -H hostname [options] args...
 	poikc --help
@@ -32,7 +32,7 @@ And then L<poikc> is for poeikcd.
 
 =head1 AUTHOR
 
-Yuji Suzuki E<lt>yuji.suzuki.perl@gmail.comE<gt>
+Yuji Suzuki E<lt>yujisuzuki@mail.arbolbell.jpE<gt>
 
 =head1 LICENSE
 
